/*
        Example for RS485 3 click

        Date          : May 2017
        Author        : Djordje Rosic

        Test configuration PIC32 :
        
                 MCU           :        P32MX795F512L
                 Dev. Board    :        EasyPIC Fusion v7
                 SW            :        mikroC PRO for PIC32 v3.6.1

    Description :

  This example demonstrates the use of RS495 3 click. It will print out all
  data receved by the click to UART B. It also shows how to send the data
  by sending the SEND_DATA array each time the button D0 is pressed.

  Note: Turn on switches SW12.3 and SW12.4 to enable UART B communication.
  Set button press level to high for port D.
  Put the RS495 3 click into MikroBUS slot 1 on the EasyPIC Fusion board.

*/
#include <stdint.h>

sbit SEND_DATA_PIN           at  RD0_bit;

uint8_t SEND_DATA[ 8 ] = { 'D', 'a', 't', 'a', ' ', 't', 'x', 't' };

/*
 * System Initialization
 */
static void systemInit( void )
{

    AD1PCFG = 0xFFFF;

    TRISD0_bit = 1;

    // Init UART B output
    UART5_Init( 9600 );
    // Init UART for communication with the click
    UART2_Init( 9600 );
    
}

void main()
{
    int i;
    char tmp;
    systemInit();

    while( 1 ) 
    {

        //Sends data
        if( Button(&PORTD, 0, 100, 1))
        {
            for( i = 0; i < 8; i++ )
                 UART2_Write( SEND_DATA [ i ] );
            UART5_Write_Text ("Data sent");
        }

        //Prints received data
        if(  UART2_Data_Ready () )
        {
            tmp = UART2_Read ();
            UART5_Write( tmp );
        }

    }
}